@@ -1,3 +1,4 @@
+import time
 import traceback
 
 import requests
@@ -16,21 +17,23 @@ class geturl:
         }
         self.url_list = []
         self.err_url = []
+        self.start_time = int(time.time())
 
     @delayed(0)
-    def request(self, url, domain):
+    def request(self, url, domain, timeout, count):
         try:
             res = requests.get(url, headers=self.header, timeout=3)
             res.encoding = res.apparent_encoding
             html = res.text
-            self.all_url(html, domain)
+            self.all_url(html, domain, timeout, count)
         except:
             self.err_url.append(url)
 
-    def all_url(self, resp, domain):
+    def all_url(self, resp, domain, timeout, count):
         all_url = re.findall('href="(.+?)"', resp)
         for link in all_url:
-            if (link.startswith('http')) and (link not in self.url_list) and (domain in link):
+            if (link.startswith('http')) and (link not in self.url_list) and (domain in link) and \
+                    (len(url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
                 self.url_list.append(link)
                 f = open('url.txt', 'a+', encoding='utf-8')
                 f.write(str(link) + '\n')
@@ -38,11 +41,11 @@ class geturl:
                 print(link)
                 self.request(link, domain)
 
-    def startres(self, url, domain):
-        self.request(url, domain)
+    def startres(self, url, domain, timeout, count):
+        self.request(url, domain, timeout, count)
         return self.url_list
 
 
 if __name__ == '__main__':
     allurl = geturl()
-    url_list = allurl.startres('https://blog.csdn.net', 'csdn.net')
\ No newline at end of file
+    url_list = allurl.startres('https://blog.csdn.net', 'csdn.net', 300, 300)
\ No newline at end of file
